summaryrefslogtreecommitdiffstats
path: root/krandr/randr.h
diff options
context:
space:
mode:
Diffstat (limited to 'krandr/randr.h')
-rw-r--r--krandr/randr.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/krandr/randr.h b/krandr/randr.h
index b4c830f02..bec5f1b61 100644
--- a/krandr/randr.h
+++ b/krandr/randr.h
@@ -211,8 +211,8 @@ public:
/**
* Configuration functions.
*/
- void load(KConfig& config);
- void save(KConfig& config) const;
+ void load(TDEConfig& config);
+ void save(TDEConfig& config) const;
private:
RandRScreenPrivate* d;
@@ -271,15 +271,15 @@ public:
/**
* Loads saved settings.
*
* @param config the KConfig object to load from
* @param loadScreens whether to call RandRScreen::load() for each screen
* @retuns true if the settings should be applied on KDE startup.
*/
- bool loadDisplay(KConfig& config, bool loadScreens = true);
- void saveDisplay(KConfig& config, bool applyOnStartup, bool syncTrayApp);
+ bool loadDisplay(TDEConfig& config, bool loadScreens = true);
+ void saveDisplay(TDEConfig& config, bool applyOnStartup, bool syncTrayApp);
- static bool applyOnStartup(KConfig& config);
- static bool syncTrayApp(KConfig& config);
+ static bool applyOnStartup(TDEConfig& config);
+ static bool syncTrayApp(TDEConfig& config);
void applyProposed(bool confirm = true);
@@ -271,15 +271,15 @@ public:
* Loads saved settings.
*
- * @param config the KConfig object to load from
+ * @param config the TDEConfig object to load from
* @param loadScreens whether to call RandRScreen::load() for each screen
* @retuns true if the settings should be applied on KDE startup.